@@ -11,7 +11,7 @@
 from heapq import nlargest
 from operator import itemgetter
 from functools import wraps
-from itertools import count, izip, repeat, ifilter
+from itertools import count, repeat
 try:
     import queue
 except ImportError:
@@ -19,6 +19,7 @@ except ImportError:
 
 from brownie.itools import izip_longest, starmap, unique, chain
 from brownie.abstract import AbstractClassMeta
+from brownie.pycompat import izip, ifilter
 
 
 class Missing(object):
@@ -524,6 +525,29 @@ class OrderedDict(dict):
         key = (reversed(self) if last else iter(self)).next()
         return key, OrderedDict.pop(self, key)
 
+    def move_to_end(self, key, last=True):
+        """
+        Moves the item with the given `key` to the end of the dictionary if
+        `last` is ``True`` otherwise to the beginning.
+
+        Raises :exc:`KeyError` if no item with the given `key` exists.
+
+        .. versionadded:: 0.4
+        """
+        if key not in self:
+            raise KeyError(key)
+        link = self._map[key]
+        prev, next = link.prev, link.next
+        prev.next, next.prev = next, prev
+        if last:
+            replacing = self._root.prev
+            replacing.next = self._root.prev = link
+            link.prev, link.next = replacing, self._root
+        else:
+            replacing = self._root.next
+            self._root.next = replacing.prev = link
+            link.prev, link.next = self._root, replacing
+
     def update(self, *args, **kwargs):
         """
         Updates the dictionary with a mapping and/or from keyword arguments.
@@ -630,6 +654,8 @@ class ImmutableOrderedDict(ImmutableDictMixin, OrderedDict):
 
     virtual_superclasses = (ImmutableDict, )
 
+    move_to_end = raise_immutable
+
     __repr__ = OrderedDict.__repr__
 
 
@@ -640,7 +666,7 @@ class OrderedMultiDict(MultiDictMixin, OrderedDict):
     virtual_superclasses = (MultiDict, )
 
 
-class ImmutableOrderedMultiDict(ImmutableMultiDictMixin, OrderedDict):
+class ImmutableOrderedMultiDict(ImmutableMultiDictMixin, ImmutableOrderedDict):
     """An immutable :class:`OrderedMultiDict`."""
     __metaclass__ = AbstractClassMeta
 
@@ -909,8 +935,7 @@ class LazyList(object):
 
         This method exhausts the internal iterator up until the given `index`.
         """
-        if index >= self.known_length or index < 0:
-            self._exhaust(index)
+        self._exhaust(index)
         self._collected_data.insert(index, object)
 
     def pop(self, index=None):
@@ -1308,7 +1333,7 @@ class SetQueue(queue.Queue):
     Ordered set queues are useful when implementing data structures like
     event buses or event queues where duplicate events need to be coalesced
     into a single event. An example use case is the inotify API in the Linux
-    kernel which shares the same behavior.
+    kernel which shares the same behaviour.
 
     Queued items must be immutable and hashable so that they can be used as
     dictionary keys or added to sets. Items must have only read-only properties
